@@ -4,7 +4,7 @@
  * This file is part of pgFouine.
  * 
  * pgFouine - a PostgreSQL log analyzer
- * Copyright (c) 2005-2006 Guillaume Smet
+ * Copyright (c) 2005-2008 Guillaume Smet
  *
  * pgFouine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ class PostgreSQLContinuationLine extends PostgreSQLLogLine {
 
 	function PostgreSQLContinuationLine($text, $duration = false) {
 		$text = str_replace('^I', "\t", $text);
-		if(substr(trim($text), 0, 2) == '--') {
+		if(substr(trim($text), 0, 2) == '--' && !CONFIG_KEEP_FORMATTING) {
 			$text = false;
 		}
 		$this->PostgreSQLLogLine($text);
